#PBS -l nodes=8:ppn=8
#PBS -l walltime=24:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

import numpy as np
from ase import Atoms, Atom
from ase.lattice.surface import fcc111, add_adsorbate
from ase.visualize import view
from ase.io import read

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

#write('step.Pt.traj', system)
#view(system)
#raise SystemExit
system = read('CO.top_edge.Pt.211step.traj')

calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=len(system) * 6,
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(sl_default=(4, 2, 32)),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )

system.set_calculator(calc)
system.get_potential_energy()
calc.write('restart.gpw')
