#PBS -l nodes=8:ppn=8
#PBS -l walltime=20:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.lattice.surface import fcc111, add_adsorbate
from ase.visualize import view

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

system = fcc111('Pt', a=3.999, size=(4, 4, 6), orthogonal=True)
system.center(vacuum=6.0, axis=2)
system.positions[:, 2] -= 1.0

calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=6 * len(system),
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(scalapack=(4, 2, 32)),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )

add_adsorbate(system, 'O', 1.28670742509, 'fcc')
system.set_calculator(calc)
system.get_potential_energy()
calc.write('restart.gpw')
