#PBS -l nodes=4:ppn=8
#PBS -l walltime=20:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase import Atoms
from ase.lattice.surface import fcc100, add_adsorbate
from ase.visualize import view

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

system = fcc100('Pt', a=3.999, size=(4, 4, 6))

CO = Atoms('CO', positions=[[0.,0.,0.],[0.,0.,1.150]])
add_adsorbate(system, CO, 1.9, 'ontop')
system.center(vacuum=5.0, axis=2)

calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=6 * len(system),
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )

system.pop()
system.pop()

system.set_calculator(calc)
system.get_potential_energy()
calc.write('restart.gpw')
