#PBS -l nodes=4:ppn=8
#PBS -l walltime=20:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

import numpy as np
from ase import Atoms, Atom
from ase.lattice.surface import fcc111, add_adsorbate
from ase.visualize import view

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

def surf_211(mat, a0):
   repeat = (2, 2, 3)
   cell=[[repeat[0]*a0*np.sqrt(3.), 0, 0],
          [0, repeat[1]*np.sqrt(2.)*a0, 0],
          [0, 0, repeat[2]*4.89897947*a0]]

   atoms=Atoms([Atom(mat, (0, 0, 0),tag=1),
                   Atom(mat, (0, 0.5, 0),tag=1),
                   Atom(mat, (0.3333, 0.25, -0.0416667),tag=1),
                   Atom(mat, (0.3333, 0.75, -0.0416667),tag=1),
                   Atom(mat, (0.66667, 0, -0.083333),tag=1),
                   Atom(mat, (0.66667, 0.5, -0.083333),tag=1),
                   Atom(mat, (0.00000000 ,    0.25000000,-0.12500000 )),
                   Atom(mat, (0.00000000 ,    0.75000000 ,-0.12500000)),
                   Atom(mat, (0.33333333 ,    0.00000000 ,-0.16666667)),
                   Atom(mat, (0.33333333 ,    0.50000000 ,-0.16666667)),
                   Atom(mat, (0.66666667 ,    0.25000000 ,-0.20833333)),
                   Atom(mat, (0.66666667 ,    0.75000000 ,-0.20833333)),
                   #Atom(mat, (0.00000000 ,    0.00000000 ,-0.25000000)),
                   #Atom(mat, (0.00000000 ,    0.50000000 ,-0.25000000)),
                   #Atom(mat, (0.33333333 ,    0.25000000 ,-0.29166667)),
                   #Atom(mat, (0.33333333 ,    0.75000000 ,-0.29166667)),
                   #Atom(mat, (0.66666667 ,    0.00000000 ,-0.33333333)),
                   #Atom(mat, (0.66666667 ,    0.50000000 ,-0.33333333))
                ])

   atoms.positions[:, 2] *= 0.5 / 0.125
   atoms = atoms.repeat(repeat)
   atoms.positions[:, 2] /= 0.5 / 0.125

   atoms.set_cell(cell, scale_atoms=True)
   atoms.set_pbc(True)
   c=atoms.cell
   c[2][2]= 25.0
   #c[2][2]=np.ceil(c[2][2] / grid_spacing) * grid_spacing
   atoms.set_cell(c)

   adsorbate = Atoms('CO', positions=[[0., 0., 0.], [0., 0., 1.150]])
   adsorbate.positions += atoms.positions[24] + [0., 0., 1.8]
   atoms += adsorbate

   atoms.center(vacuum=5.0, axis=2)
   return atoms


system = surf_211('Pt', 3.999)
system.center(vacuum=6.0, axis=2)
system.positions[:, 2] -= 1.0
from ase.io import write
write('step.Pt.traj', system)
#view(system)
raise SystemExit


calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=len(system) * 6,
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(scalapack=(4, 2, 32)),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )

#add_adsorbate(system, adsorbate, 1.900, 'ontop')
system.set_calculator(calc)
system.get_potential_energy()
calc.write('restart.gpw')
