#PBS -l nodes=12:ppn=4:opteron
#PBS -l walltime=7:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase import Atoms
from ase.lattice.surface import fcc110, add_adsorbate
from ase.visualize import view
from ase.constraints import FixAtoms, FixedLine
from ase.io import write
from ase.optimize import QuasiNewton

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

system = fcc110('Pt', a=3.999, size=(2, 3, 8))
system.positions[:, 2] -= 1.0

molecule = Atoms('CO', positions=[[0.,0.,0.],[0.,0.,1.150]])
add_adsorbate(system, molecule, 1.4, 'shortbridge')
system.center(vacuum=5.0, axis=2)

system.pop(-1)
system.pop(-1)

#fixconstraint = FixAtoms(indices=range(len(system) - 1))
#lineconstraint1 = FixedLine(len(system)-1, [0.,0.,1])
#lineconstraint2 = FixedLine(len(system)-2, [0.,0.,1])
#system.set_constraint([fixconstraint, lineconstraint1, lineconstraint2])
#system.pop(-1)
#system.pop(-1)

write('system0.traj', system)

calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=int(5.6 * len(system)),
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(scalapack=(4, 2, 32)),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )


system.set_calculator(calc)

#opt = QuasiNewton(system, trajectory='opt.traj', logfile='opt.log')
#opt.run(fmax=0.05)

system.get_potential_energy()
calc.write('restart.gpw')
