#PBS -l nodes=24:ppn=4:opteron
#PBS -l walltime=20:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.lattice.surface import fcc110, add_adsorbate
from ase.visualize import view
from ase.constraints import FixAtoms
from ase.io import write
from ase.optimize import QuasiNewton

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

system = fcc110('Pt', a=3.999, size=(2, 3, 8))
system.center(vacuum=5.0, axis=2)
system.positions[:, 2] -= 1.0

calc = GPAW(#mode='lcao',
            #basis='dzp',
            kpts=(4, 4, 1),
            nbands=int(5.6 * len(system)),
            xc='RPBE',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(scalapack=(4, 2, 32)),
            txt='gpaw.txt',
            gpts=h2gpts(0.17, system.get_cell(), idiv=8),
            poissonsolver=PoissonSolver(relax='GS')
            )

add_adsorbate(system, 'O', 1.4, 'shortbridge')

constraint = FixAtoms(indices=range(len(system) - 1))
system.set_constraint(constraint)
write('system0.traj', system)

system.set_calculator(calc)

opt = QuasiNewton(system, trajectory='opt.traj', logfile='opt.log')
opt.run(fmax=0.05)

system.get_potential_energy()
calc.write('restart.gpw')
