#PBS -l nodes=1:ppn=8
#PBS -l walltime=13:0:0
#PBS -m ae
#PBS -o stdout.log
#PBS -e stderr.log

from ase.lattice.surface import fcc111, add_adsorbate
from ase.visualize import view

from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

calc = GPAW(mode='lcao',
            basis='dzp',
            kpts=(4, 4, 1),
            xc='RPBE',
            txt='gpaw.txt',
            mixer=Mixer(0.03, 9, 100.0),
            parallel=dict(scalapack=(4, 2, 32)),
            poissonsolver=PoissonSolver(relax='GS')
            )

system = fcc111('Pt', a=3.999, size=(4, 4, 8), orthogonal=True)
system.center(vacuum=6.0, axis=2)
system.positions[:, 2] -= 1.0

calc.set(gpts=h2gpts(0.17, system.get_cell(), idiv=8))
calc.set(txt='gpaw.surface.%02d.txt' % layers)

system.set_calculator(calc)
system.get_potential_energy()

add_adsorbate(system, 'O', 1.28670742509, 'fcc')
calc.set(txt='gpaw.full.%02d.txt' % layers)
system.get_potential_energy()

